<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nombre_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Proximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Select ISO</source>
        <translation>Seleccione ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione Dispositivo USB Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione fichero ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosidad (de menos a más)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamaño del partición ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Crear el sistema de ficheros de ext4 aunque exista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guarda la carpeta original de inicio cuando actualice un live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usar particionamiento gpt en vez de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>GPT partitioning</source>
        <translation>Particionamiento GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizar (solamente actualiza un liveUSB existente)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>No reemplazar ficheros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <source>Keep syslinux files</source>
        <translation>Mantener ficheros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar chequeo USB/removible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Temporarily disable automounting</source>
        <translation>Temporalmente deshabilitar automontaje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Fijar bandera disco a pmbr_boot (no iniciar via UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Refresh drive list</source>
        <translation>Refrescar lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>Show advanced options</source>
        <translation>Mostrar opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Modo de funciones completas - LiveUSB escribible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Leer solamente, no soporta persistencía</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="512"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Modo imagen - LiveUSB solo escribible (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Para distros no antiX/MX utilizar el modo imagen (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>Percent of USB-device to use:</source>
        <translation>Porcentaje del dispositivo USB a utilizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="616"/>
        <source>Label ext partition:</source>
        <translation>Etiqueta para partición ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>No ejecuta comandos que afecta el dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Dry run (no change to system)</source>
        <translation>Modo simulación (ningún cambio al sistema)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonar de un liveUSB montado o un fichero ISO.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Clone an existing live system</source>
        <translation>Clonar un sistema en vivo existente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurar para iniciar desde una partición cifrada; preguntará la frase de paso en el primer arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Encrypt</source>
        <translation>Cifrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Clone running live system</source>
        <translation>Clonar el sistema que se ejecuta en vivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Failure</source>
        <translation>Falla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>La fuente y el destino están en el mismo dispositivo; seleccionar de nuevo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Escribiendo %1 con el comando &apos;dd&apos; hacia /dev/%2,

Favor espere hasta que el proceso termine.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>LiveUSB creation successful!</source>
        <translation>¡Creación del LiveUSB exitosa!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Se encontró un error en el proceso de creación del LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Please select a USB device to write to</source>
        <translation>Favor seleccione el dispositivo USB al cual escribir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para crear liveUSB desde un fichero ISO, otro liveUSB, liveCD/DVD, o un sistema actualmente en ejecución.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccione fichero ISO para escribir al USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Select Source Directory</source>
        <translation>Seleccione Carpeta Fuente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>No encontró el fichero %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Hide advanced options</source>
        <translation>Esconder opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Select Source</source>
        <translation>Seleccionar Fuente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Select ISO file</source>
        <translation>Seleccionar fichero ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as root.</source>
        <translation>Debe ejecutar este programa como root.</translation>
    </message>
</context>
</TS>
